@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: asn1-parse
 version: 0.9.4
-id: asn1-parse-0.9.4-fd3a08c795c9c8864b1d7fa62a124c6b
-key: asn1p_EiOXJi5vJrMCUEWoS1An79
+id: asn1-parse-0.9.4-7a8ff0bd98d1e72c778de11c366d8b51
+key: asn1p_LrLFPvrxagO8jGmFd1SmqK
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-parse-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-parse-0.9.4
-hs-libraries: HSasn1-parse-0.9.4-EiOXJi5vJrMCUEWoS1An79
+hs-libraries: HSasn1-parse-0.9.4-LrLFPvrxagO8jGmFd1SmqK
 depends:
-    asn1-encoding-0.9.3-61b8646033da9bb10b3d5eef2c9988e8
-    asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
+    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
+    asn1-types-0.3.2-3969820adc8283f126affe054010f830
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
 haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
